@@ -62,17 +62,17 @@ oneToOneTraverse <- function(map,
                              copyMap = TRUE,
                              verbose = FALSE) {
     if (!(traversalType %in% as.list(TraversalType))) {
-        stop("Unknown traversalType: ", traversalType)
+        stop("Unknown traversalType: ", traversalType, call. = FALSE)
     }
 
     if (!is.na(quantizationWidth) && !inherits(map, "SegmentShapeGraph")) {
-        stop("quantizationWidth can only be used with Segment ShapeGraphs")
+        stop("quantizationWidth can only be used with Segment ShapeGraphs", call. = FALSE)
     }
 
     if (is.na(quantizationWidth) &&
             inherits(map, "SegmentShapeGraph") &&
             traversalType == TraversalType$Angular) {
-        stop("Angular traversal requires a quantizationWidth")
+        stop("Angular traversal requires a quantizationWidth", call. = FALSE)
     }
     return(oneToOneTraversePerMapType(
         map,
@@ -108,7 +108,7 @@ oneToOneTraversePerMapType <- function(map,
             verbose
         ))
     } else if (inherits(map, "AxialShapeGraph")) {
-        stop("Shortest paths are not available for Axial ShapeGraphs")
+        stop("Shortest paths are not available for Axial ShapeGraphs", call. = FALSE)
     } else if (inherits(map, "SegmentShapeGraph")) {
         tulipBins <- 0L
         if (traversalType == TraversalType$Angular &&
@@ -124,7 +124,7 @@ oneToOneTraversePerMapType <- function(map,
         )
         return(processShapeMapResult(map, result))
     } else {
-        stop("Can only run depth on Axial or Segment ShapeGraphs and PointMaps")
+        stop("Can only run depth on Axial or Segment ShapeGraphs and PointMaps", call. = FALSE)
     }
 }
 
