@@ -4,9 +4,9 @@
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
-#include "axialstepdepth.h"
+#include "axialstepdepth.hpp"
 
-#include "../genlib/pflipper.h"
+#include "../genlib/pflipper.hpp"
 
 AnalysisResult AxialStepDepth::run(Communicator *, ShapeGraph &map, bool) {
 
@@ -14,18 +14,19 @@ AnalysisResult AxialStepDepth::run(Communicator *, ShapeGraph &map, bool) {
 
     AnalysisResult result;
 
-    int stepdepthCol = attributes.insertOrResetColumn(Column::STEP_DEPTH);
+    auto stepdepthCol = attributes.insertOrResetColumn(Column::STEP_DEPTH);
     result.addAttribute(Column::STEP_DEPTH);
 
     bool *covered = new bool[map.getConnections().size()];
     for (size_t i = 0; i < map.getConnections().size(); i++) {
         covered[i] = false;
     }
-    pflipper<std::vector<int>> foundlist;
+    pflipper<std::vector<size_t>> foundlist;
     for (auto &lineindex : m_originRefs) {
-        foundlist.a().push_back(lineindex);
+        foundlist.a().push_back(static_cast<size_t>(lineindex));
         covered[lineindex] = true;
-        map.getAttributeRowFromShapeIndex(lineindex).setValue(stepdepthCol, 0.0f);
+        map.getAttributeRowFromShapeIndex(static_cast<size_t>(lineindex))
+            .setValue(stepdepthCol, 0.0f);
     }
     int depth = 1;
     while (foundlist.a().size()) {
@@ -35,7 +36,7 @@ AnalysisResult AxialStepDepth::run(Communicator *, ShapeGraph &map, bool) {
                 covered[line.connections[k]] = true;
                 foundlist.b().push_back(line.connections[k]);
                 map.getAttributeRowFromShapeIndex(line.connections[k])
-                    .setValue(stepdepthCol, float(depth));
+                    .setValue(stepdepthCol, static_cast<float>(depth));
             }
         }
         foundlist.a().pop_back();
