@@ -2,11 +2,11 @@
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
-#include "importutils.h"
+#include "importutils.hpp"
 
-#include "genlib/stringutils.h"
-#include "parsers/ntfp.h"
-#include "parsers/tigerp.h"
+#include "genlib/stringutils.hpp"
+#include "parsers/ntfp.hpp"
+#include "parsers/tigerp.hpp"
 
 #include <sstream>
 
@@ -16,7 +16,7 @@ namespace depthmapX {
 
     class ImportError : public BaseException {
       public:
-        ImportError(std::string message) : BaseException(message) {}
+        ImportError(std::string message) : BaseException(std::move(message)) {}
     };
 
     std::vector<ShapeMap> importFile(std::istream &stream, Communicator *communicator,
@@ -193,7 +193,7 @@ namespace depthmapX {
                                                           ? ShapeMap::DATAMAP
                                                           : ShapeMap::DRAWINGMAP);
 
-        shapeMap.init(numlines, QtRegion(minPoint, maxPoint));
+        shapeMap.init(numlines, Region4f(minPoint, maxPoint));
 
         // in MSVC 6, ios::eof remains set and it needs to be cleared.
         // in MSVC 8 it's even worse: it won't even seekg until eof flag has been
@@ -224,7 +224,7 @@ namespace depthmapX {
                             shapeMap.makePolyShape(points, true);
                         }
                     } else if (points.size() == 2) {
-                        shapeMap.makeLineShape(Line(points[0], points[1]));
+                        shapeMap.makeLineShape(Line4f(points[0], points[1]));
                     }
                     points.clear();
                     parsing = 0;
@@ -295,36 +295,38 @@ namespace depthmapX {
         int xcol = -1, ycol = -1, x1col = -1, y1col = -1, x2col = -1, y2col = -1, refcol = -1;
         for (auto const &column : table) {
             if (column.first == "x" || column.first == "easting")
-                xcol = columns.size();
+                xcol = static_cast<int>(columns.size());
             else if (column.first == "y" || column.first == "northing")
-                ycol = columns.size();
+                ycol = static_cast<int>(columns.size());
             else if (column.first == "x1")
-                x1col = columns.size();
+                x1col = static_cast<int>(columns.size());
             else if (column.first == "x2")
-                x2col = columns.size();
+                x2col = static_cast<int>(columns.size());
             else if (column.first == "y1")
-                y1col = columns.size();
+                y1col = static_cast<int>(columns.size());
             else if (column.first == "y2")
-                y2col = columns.size();
+                y2col = static_cast<int>(columns.size());
             else if (column.first == "Ref")
-                refcol = columns.size();
+                refcol = static_cast<int>(columns.size());
             columns.push_back(column.first);
         }
 
         if (xcol != -1 && ycol != -1 && refcol != -1) {
-            std::map<int, Point2f> points = extractPointsWithRefs(
-                table[columns[xcol]], table[columns[ycol]], table[columns[refcol]]);
-            table.erase(table.find(columns[xcol]));
-            table.erase(table.find(columns[ycol]));
-            table.erase(table.find(columns[refcol]));
+            std::map<int, Point2f> points =
+                extractPointsWithRefs(table[columns[static_cast<size_t>(xcol)]],
+                                      table[columns[static_cast<size_t>(ycol)]],
+                                      table[columns[static_cast<size_t>(refcol)]]);
+            table.erase(table.find(columns[static_cast<size_t>(xcol)]));
+            table.erase(table.find(columns[static_cast<size_t>(ycol)]));
+            table.erase(table.find(columns[static_cast<size_t>(refcol)]));
 
-            QtRegion region;
+            Region4f region;
 
             for (auto &point : points) {
                 if (region.atZero()) {
                     region = point.second;
                 } else {
-                    region = runion(region, point.second);
+                    region = region.runion(point.second);
                 }
             }
 
@@ -332,17 +334,18 @@ namespace depthmapX {
             shapeMap.importPointsWithRefs(points, table);
 
         } else if (xcol != -1 && ycol != -1) {
-            std::vector<Point2f> points = extractPoints(table[columns[xcol]], table[columns[ycol]]);
-            table.erase(table.find(columns[xcol]));
-            table.erase(table.find(columns[ycol]));
+            std::vector<Point2f> points = extractPoints(table[columns[static_cast<size_t>(xcol)]],
+                                                        table[columns[static_cast<size_t>(ycol)]]);
+            table.erase(table.find(columns[static_cast<size_t>(xcol)]));
+            table.erase(table.find(columns[static_cast<size_t>(ycol)]));
 
-            QtRegion region;
+            Region4f region;
 
             for (auto &point : points) {
                 if (region.atZero()) {
                     region = point;
                 } else {
-                    region = runion(region, point);
+                    region = region.runion(point);
                 }
             }
 
@@ -350,22 +353,25 @@ namespace depthmapX {
             shapeMap.importPoints(points, table);
 
         } else if (x1col != -1 && y1col != -1 && x2col != -1 && y2col != -1 && refcol != -1) {
-            std::map<int, Line> lines = extractLinesWithRef(
-                table[columns[x1col]], table[columns[y1col]], table[columns[x2col]],
-                table[columns[y2col]], table[columns[refcol]]);
-            table.erase(table.find(columns[x1col]));
-            table.erase(table.find(columns[y1col]));
-            table.erase(table.find(columns[x2col]));
-            table.erase(table.find(columns[y2col]));
-            table.erase(table.find(columns[refcol]));
+            std::map<int, Line4f> lines =
+                extractLinesWithRef(table[columns[static_cast<size_t>(x1col)]],
+                                    table[columns[static_cast<size_t>(y1col)]],
+                                    table[columns[static_cast<size_t>(x2col)]],
+                                    table[columns[static_cast<size_t>(y2col)]],
+                                    table[columns[static_cast<size_t>(refcol)]]);
+            table.erase(table.find(columns[static_cast<size_t>(x1col)]));
+            table.erase(table.find(columns[static_cast<size_t>(y1col)]));
+            table.erase(table.find(columns[static_cast<size_t>(x2col)]));
+            table.erase(table.find(columns[static_cast<size_t>(y2col)]));
+            table.erase(table.find(columns[static_cast<size_t>(refcol)]));
 
-            QtRegion region;
+            Region4f region;
 
             for (auto &line : lines) {
                 if (region.atZero()) {
                     region = line.second;
                 } else {
-                    region = runion(region, line.second);
+                    region = region.runion(line.second);
                 }
             }
 
@@ -373,20 +379,22 @@ namespace depthmapX {
             shapeMap.importLinesWithRefs(lines, table);
 
         } else if (x1col != -1 && y1col != -1 && x2col != -1 && y2col != -1) {
-            std::vector<Line> lines = extractLines(table[columns[x1col]], table[columns[y1col]],
-                                                   table[columns[x2col]], table[columns[y2col]]);
-            table.erase(table.find(columns[x1col]));
-            table.erase(table.find(columns[y1col]));
-            table.erase(table.find(columns[x2col]));
-            table.erase(table.find(columns[y2col]));
+            std::vector<Line4f> lines = extractLines(table[columns[static_cast<size_t>(x1col)]],
+                                                     table[columns[static_cast<size_t>(y1col)]],
+                                                     table[columns[static_cast<size_t>(x2col)]],
+                                                     table[columns[static_cast<size_t>(y2col)]]);
+            table.erase(table.find(columns[static_cast<size_t>(x1col)]));
+            table.erase(table.find(columns[static_cast<size_t>(y1col)]));
+            table.erase(table.find(columns[static_cast<size_t>(x2col)]));
+            table.erase(table.find(columns[static_cast<size_t>(y2col)]));
 
-            QtRegion region;
+            Region4f region;
 
             for (auto &line : lines) {
                 if (region.atZero()) {
                     region = line;
                 } else {
-                    region = runion(region, line);
+                    region = region.runion(line);
                 }
             }
 
@@ -423,47 +431,48 @@ namespace depthmapX {
         while (!stream.eof()) {
             std::getline(stream, inputline);
             if (!inputline.empty()) {
-                auto strings = dXstring::split(inputline, delimiter);
-                if (strings.size() != columns.size()) {
+                auto inputStrings = dXstring::split(inputline, delimiter);
+                if (inputStrings.size() != columns.size()) {
                     std::stringstream message;
                     message << "Cells in line " << inputline
                             << " not the same number as the columns" << std::flush;
                     throw RuntimeException(message.str().c_str());
                 }
-                if (!strings.size()) {
+                if (!inputStrings.size()) {
                     continue;
                 }
-                for (size_t i = 0; i < strings.size(); i++) {
-                    table[columns[i]].push_back(strings[i]);
+                for (size_t i = 0; i < inputStrings.size(); i++) {
+                    table[columns[i]].push_back(inputStrings[i]);
                 }
             }
         }
         return table;
     }
 
-    std::vector<Line> extractLines(ColumnData &x1col, ColumnData &y1col, ColumnData &x2col,
-                                   ColumnData &y2col) {
-        std::vector<Line> lines;
+    std::vector<Line4f> extractLines(ColumnData &x1col, ColumnData &y1col, ColumnData &x2col,
+                                     ColumnData &y2col) {
+        std::vector<Line4f> lines;
         for (size_t i = 0; i < x1col.size(); i++) {
             double x1 = stod(x1col[i]);
             double y1 = stod(y1col[i]);
             double x2 = stod(x2col[i]);
             double y2 = stod(y2col[i]);
-            lines.push_back(Line(Point2f(x1, y1), Point2f(x2, y2)));
+            lines.push_back(Line4f(Point2f(x1, y1), Point2f(x2, y2)));
         }
         return lines;
     }
 
-    std::map<int, Line> extractLinesWithRef(ColumnData &x1col, ColumnData &y1col, ColumnData &x2col,
-                                            ColumnData &y2col, ColumnData &refcol) {
-        std::map<int, Line> lines;
+    std::map<int, Line4f> extractLinesWithRef(ColumnData &x1col, ColumnData &y1col,
+                                              ColumnData &x2col, ColumnData &y2col,
+                                              ColumnData &refcol) {
+        std::map<int, Line4f> lines;
         for (size_t i = 0; i < x1col.size(); i++) {
             double x1 = stod(x1col[i]);
             double y1 = stod(y1col[i]);
             double x2 = stod(x2col[i]);
             double y2 = stod(y2col[i]);
             int ref = stoi(refcol[i]);
-            lines.insert(std::make_pair(ref, Line(Point2f(x1, y1), Point2f(x2, y2))));
+            lines.insert(std::make_pair(ref, Line4f(Point2f(x1, y1), Point2f(x2, y2))));
         }
         return lines;
     }
@@ -484,7 +493,7 @@ namespace depthmapX {
 
     bool importDxfLayer(const DxfLayer &dxfLayer, ShapeMap &shapeMap) {
         std::vector<Point2f> points;
-        std::vector<Line> lines;
+        std::vector<Line4f> lines;
         std::vector<Polyline> polylines;
 
         for (size_t jp = 0; jp < dxfLayer.numPoints(); jp++) {
@@ -494,8 +503,8 @@ namespace depthmapX {
 
         for (size_t j = 0; j < dxfLayer.numLines(); j++) {
             const DxfLine &dxfLine = dxfLayer.getLine(j);
-            Line line = Line(Point2f(dxfLine.getStart().x, dxfLine.getStart().y),
-                             Point2f(dxfLine.getEnd().x, dxfLine.getEnd().y));
+            Line4f line = Line4f(Point2f(dxfLine.getStart().x, dxfLine.getStart().y),
+                                 Point2f(dxfLine.getEnd().x, dxfLine.getEnd().y));
             lines.push_back(line);
         }
 
@@ -506,8 +515,9 @@ namespace depthmapX {
                 DxfVertex v = poly.getVertex(m);
                 vertices.push_back(Point2f(v.x, v.y));
             }
-            polylines.push_back(depthmapX::Polyline(
-                vertices, (poly.getAttributes() & DxfPolyLine::CLOSED) == DxfPolyLine::CLOSED));
+            polylines.push_back(depthmapX::Polyline(std::move(vertices),
+                                                    (poly.getAttributes() & DxfPolyLine::CLOSED) ==
+                                                        DxfPolyLine::CLOSED));
         }
 
         for (size_t l = 0; l < dxfLayer.numSplines(); l++) {
@@ -517,34 +527,35 @@ namespace depthmapX {
                 DxfVertex v = poly.getVertex(m);
                 vertices.push_back(Point2f(v.x, v.y));
             }
-            polylines.push_back(depthmapX::Polyline(
-                vertices, (poly.getAttributes() & DxfPolyLine::CLOSED) == DxfPolyLine::CLOSED));
+            polylines.push_back(depthmapX::Polyline(std::move(vertices),
+                                                    (poly.getAttributes() & DxfPolyLine::CLOSED) ==
+                                                        DxfPolyLine::CLOSED));
         }
 
         for (size_t n = 0; n < dxfLayer.numArcs(); n++) {
             const DxfArc &circ = dxfLayer.getArc(n);
             std::vector<Point2f> vertices;
-            size_t segments = circ.numSegments(DXFCIRCLERES);
+            int segments = static_cast<int>(circ.numSegments(DXFCIRCLERES));
             if (segments > 1) {
-                for (size_t m = 0; m <= segments; m++) {
+                for (int m = 0; m <= segments; m++) {
                     DxfVertex v = circ.getVertex(m, segments);
                     vertices.push_back(Point2f(v.x, v.y));
                 }
             }
-            polylines.push_back(depthmapX::Polyline(vertices, false));
+            polylines.push_back(depthmapX::Polyline(std::move(vertices), false));
         }
 
         for (size_t n = 0; n < dxfLayer.numEllipses(); n++) {
             const DxfEllipse &ellipse = dxfLayer.getEllipse(n);
             std::vector<Point2f> vertices;
-            size_t segments = ellipse.numSegments(DXFCIRCLERES);
+            auto segments = static_cast<int>(ellipse.numSegments(DXFCIRCLERES));
             if (segments > 1) {
-                for (size_t m = 0; m <= segments; m++) {
+                for (int m = 0; m <= segments; m++) {
                     DxfVertex v = ellipse.getVertex(m, segments);
                     vertices.push_back(Point2f(v.x, v.y));
                 }
             }
-            polylines.push_back(depthmapX::Polyline(vertices, false));
+            polylines.push_back(depthmapX::Polyline(std::move(vertices), false));
         }
 
         for (size_t nc = 0; nc < dxfLayer.numCircles(); nc++) {
@@ -554,13 +565,13 @@ namespace depthmapX {
                 DxfVertex v = circ.getVertex(m, DXFCIRCLERES);
                 vertices.push_back(Point2f(v.x, v.y));
             }
-            polylines.push_back(depthmapX::Polyline(vertices, true));
+            polylines.push_back(depthmapX::Polyline(std::move(vertices), true));
         }
         DxfVertex layerMin = dxfLayer.getExtMin();
         DxfVertex layerMax = dxfLayer.getExtMax();
 
-        QtRegion region =
-            QtRegion(Point2f(layerMin.x, layerMin.y), Point2f(layerMax.x, layerMax.y));
+        Region4f region =
+            Region4f(Point2f(layerMin.x, layerMin.y), Point2f(layerMax.x, layerMax.y));
 
         shapeMap.init(points.size() + lines.size() + polylines.size(), region);
         // parameters could be passed in the Table here such as the
@@ -578,7 +589,7 @@ namespace depthmapX {
         int refcol = -1;
         for (auto const &column : table) {
             if (column.first == "Ref")
-                refcol = outColumns.size();
+                refcol = static_cast<int>(outColumns.size());
             else
                 outColumns.push_back(column.first);
         }
@@ -607,7 +618,7 @@ namespace depthmapX {
         // so no need for corrective measures yet
 
         for (const std::string &column : outColumns) {
-            int colIdx = attributes.insertOrResetColumn(column);
+            auto colIdx = attributes.insertOrResetColumn(column);
             auto outRowIter = table[column].begin();
             for (auto inRowIter = inRows.begin(); inRowIter != inRows.end();
                  inRowIter++, outRowIter++) {
