@@ -7,12 +7,11 @@
 
 // Quick Tiger line parser (type 1 records)
 
-#include "tigerp.h"
+#include "tigerp.hpp"
 
-#include "../genlib/comm.h"
+#include "../genlib/comm.hpp"
 
 #include <fstream>
-#include <iostream>
 
 // at some point will need to extend to parsing record type 2 (chains) as well as record type 1
 // (node to node)
@@ -40,16 +39,16 @@ void TigerMap::parse(const std::vector<std::string> &fileset, Communicator *comm
                     int lat1 = stoi(line.substr(200, 9));
                     int long2 = stoi(line.substr(209, 10));
                     int lat2 = stoi(line.substr(219, 9));
-                    Point2f p1(double(long1) / 1e6, double(lat1) / 1e6);
-                    Point2f p2(double(long2) / 1e6, double(lat2) / 1e6);
-                    Line li(p1, p2);
+                    Point2f p1(static_cast<double>(long1) / 1e6, static_cast<double>(lat1) / 1e6);
+                    Point2f p2(static_cast<double>(long2) / 1e6, static_cast<double>(lat2) / 1e6);
+                    Line4f li(p1, p2);
                     iter->second.chains.push_back(TigerChain());
                     iter->second.chains.back().lines.push_back(li);
                     if (!m_init) {
                         m_region = li;
                         m_init = true;
                     } else {
-                        m_region = runion(m_region, li);
+                        m_region = m_region.runion(li);
                     }
                 }
             }
